developerscripttools.RunDoctestsScript
======================================

.. inheritance-diagram:: abjad.tools.developerscripttools.RunDoctestsScript.RunDoctestsScript.RunDoctestsScript
   :private-bases:

.. autoclass:: abjad.tools.developerscripttools.RunDoctestsScript.RunDoctestsScript.RunDoctestsScript

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.developerscripttools.RunDoctestsScript.RunDoctestsScript.RunDoctestsScript.alias

.. autoattribute:: abjad.tools.developerscripttools.RunDoctestsScript.RunDoctestsScript.RunDoctestsScript.argument_parser

    Inherited from :py:class:`developerscripttools.DeveloperScript <abjad.tools.developerscripttools.DeveloperScript.DeveloperScript.DeveloperScript>`

.. autoattribute:: abjad.tools.developerscripttools.RunDoctestsScript.RunDoctestsScript.RunDoctestsScript.formatted_help

    Inherited from :py:class:`developerscripttools.DeveloperScript <abjad.tools.developerscripttools.DeveloperScript.DeveloperScript.DeveloperScript>`

.. autoattribute:: abjad.tools.developerscripttools.RunDoctestsScript.RunDoctestsScript.RunDoctestsScript.formatted_usage

    Inherited from :py:class:`developerscripttools.DeveloperScript <abjad.tools.developerscripttools.DeveloperScript.DeveloperScript.DeveloperScript>`

.. autoattribute:: abjad.tools.developerscripttools.RunDoctestsScript.RunDoctestsScript.RunDoctestsScript.formatted_version

    Inherited from :py:class:`developerscripttools.DeveloperScript <abjad.tools.developerscripttools.DeveloperScript.DeveloperScript.DeveloperScript>`

.. autoattribute:: abjad.tools.developerscripttools.RunDoctestsScript.RunDoctestsScript.RunDoctestsScript.long_description

.. autoattribute:: abjad.tools.developerscripttools.RunDoctestsScript.RunDoctestsScript.RunDoctestsScript.program_name

    Inherited from :py:class:`developerscripttools.DeveloperScript <abjad.tools.developerscripttools.DeveloperScript.DeveloperScript.DeveloperScript>`

.. autoattribute:: abjad.tools.developerscripttools.RunDoctestsScript.RunDoctestsScript.RunDoctestsScript.scripting_group

.. autoattribute:: abjad.tools.developerscripttools.RunDoctestsScript.RunDoctestsScript.RunDoctestsScript.short_description

.. autoattribute:: abjad.tools.developerscripttools.RunDoctestsScript.RunDoctestsScript.RunDoctestsScript.storage_format

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. autoattribute:: abjad.tools.developerscripttools.RunDoctestsScript.RunDoctestsScript.RunDoctestsScript.version

Methods
-------

.. automethod:: abjad.tools.developerscripttools.RunDoctestsScript.RunDoctestsScript.RunDoctestsScript.process_args

.. automethod:: abjad.tools.developerscripttools.RunDoctestsScript.RunDoctestsScript.RunDoctestsScript.setup_argument_parser

Special Methods
---------------

.. automethod:: abjad.tools.developerscripttools.RunDoctestsScript.RunDoctestsScript.RunDoctestsScript.__call__

    Inherited from :py:class:`developerscripttools.DeveloperScript <abjad.tools.developerscripttools.DeveloperScript.DeveloperScript.DeveloperScript>`

.. automethod:: abjad.tools.developerscripttools.RunDoctestsScript.RunDoctestsScript.RunDoctestsScript.__eq__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.developerscripttools.RunDoctestsScript.RunDoctestsScript.RunDoctestsScript.__ge__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.developerscripttools.RunDoctestsScript.RunDoctestsScript.RunDoctestsScript.__gt__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.developerscripttools.RunDoctestsScript.RunDoctestsScript.RunDoctestsScript.__le__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.developerscripttools.RunDoctestsScript.RunDoctestsScript.RunDoctestsScript.__lt__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.developerscripttools.RunDoctestsScript.RunDoctestsScript.RunDoctestsScript.__ne__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.developerscripttools.RunDoctestsScript.RunDoctestsScript.RunDoctestsScript.__repr__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`
